# Lab_Automation

Lab_Automation: automated scripts for all kinds of devices.
PyLab:
* **<measure_devices>** measure devices based on PyLab.
* **<image_devices>** different types of CCD and SLM, etc.
* **<other_devices>** functional devices like rotation plaform.